from typing import Any
from haskellian import Either
from .types import GroupPairings, PairingsSource

async def scrape_pairings(source: PairingsSource) -> Either[Any, GroupPairings]:
  match source.root.tag:
    case 'chess-results':
      from .chess_results import scrape_pairings
      return await scrape_pairings(source.root.db_key)


from typing import Literal
from pydantic import BaseModel, RootModel, Field

class ChessResultsPairings(BaseModel):
  tag: Literal['chess-results'] = 'chess-results'
  db_key: int

class PairingsSource(RootModel):
  root: ChessResultsPairings = Field(discriminator='tag')


from .types import Result, Paired, Unpaired, Pairing, RoundPairings, GroupPairings, TournamentPairings, \
  GameId, GroupId, RoundId, gameId, roundId, groupId, GamesMapping, stringifyId, \
  ChessResultsPairings, PairingsSource
from ._classify import classify
from ._scrape import scrape_pairings
from . import chess_results

__all__ = [
  'Result', 'Paired', 'Unpaired', 'Pairing', 'RoundPairings', 'GroupPairings', 'TournamentPairings',
  'GameId', 'GroupId', 'RoundId', 'gameId', 'roundId', 'groupId', 'GamesMapping',
  'classify', 'stringifyId', 'scrape_pairings',
  'chess_results', 'ChessResultsPairings', 'PairingsSource',
]